Market data models.
These models represent responses from public market data endpoints.
Modules
- string_
or_ float - Helper module for deserializing string or float values.
- string_
or_ float_ opt - Helper module for deserializing optional string or float values.
Structs
- AggTrade
- Aggregate trade.
- Average
Price - Average price response.
- Book
Ticker - Symbol order book ticker (best bid/ask).
- Exchange
Info - Exchange information response.
- Kline
- Kline/candlestick data.
- Order
Book - Order book response.
- Order
Book Entry - Order book entry (price level).
- Rate
Limit - Rate limit information.
- Rolling
Window Ticker - Rolling window ticker statistics (FULL).
- Rolling
Window Ticker Mini - Rolling window ticker statistics (MINI).
- Server
Time - Server time response.
- Symbol
- Trading symbol information.
- Ticker24h
- 24hr ticker price change statistics.
- Ticker
Price - Symbol price ticker.
- Trade
- Recent trade.
- Trading
DayTicker - Trading day ticker statistics (FULL).
- Trading
DayTicker Mini - Trading day ticker statistics (MINI).
Enums
- Symbol
Filter - Symbol filter types.