pub enum ExecutionType {
New,
Canceled,
Replaced,
Rejected,
Trade,
Expired,
TradePrevention,
Amendment,
}Expand description
Execution type for order updates.
Variants
New
The order has been accepted into the engine
Canceled
The order has been canceled by the user
Replaced
Currently unused
Rejected
The order has been rejected
Trade
Part of the order or all of the order’s quantity has filled
Expired
The order was canceled according to the order type’s rules
TradePrevention
The order has expired due to STP trigger
Amendment
Order modified